==> sale-3.5.1.jar: filiale/zhongyi/sqls/getPlan.sql <==
select * from(
     select
            h.*,
            sp.f_price_type,
            case when isnull(uf.f_capacity, 0) > 0 then uf.f_capacity else gm.f_capacity end f_capacity, --表最大量程
            u.f_balance balance,
            u.f_user_level,
            address.f_slice_area f_zones,
            address.f_residential_area area,
            avggas,
            substring(convert(varchar(100),h.f_hand_date,23),0,8) belongmonth,
            h1.maxid
     from  t_handplan h
         left join t_userfiles uf on h.f_userfiles_id=uf.f_userfiles_id
         left join (
             select f_userfiles_id,max(id) maxid,
                sum(f_oughtamount)/count(*) avggas
             from t_handplan
             where f_hand_state='有效' group by  f_userfiles_id
         )   h1 on h.f_userfiles_id=h1.f_userfiles_id
         LEFT JOIN t_userinfo u ON h.f_userinfo_id = u.f_userinfo_id
         left join t_gasbrand gb on uf.f_gasbrand_id = gb.id
         left join t_gasmodel gm on uf.f_gasmodel_id=gm.id
         left join t_meter_book mb on uf.f_meter_book_num=mb.id
         left join t_user_address address on uf.f_useraddress_id = address.id
         left join (select * from t_stairprice where getdate()>=f_perform_date and getdate()<=f_end_date and f_state = '有效') sp on h.f_price_id = sp.f_price_id
     where f_hand_state='有效'  AND  h.f_meter_classify = '机表'
     AND f_table_state = '正常' and f_user_state='正常'
)t
where {condition}
order by {orderitem},f_meter_book_num,f_meter_book_sort,f_residential_area,f_floor,f_adjustable_id

==> sale-3.7.1.jar: filiale/zhongyi/sqls/getPlan.sql <==
select * from(
     select
            h.*,
            case when  (year(GETDATE())- year(case when h.f_last_input_date is null then uf.f_hand_date else h.f_last_input_date  end))>0 then 1 else 0 end   crossyear,
            sp.f_price_type,
            case when isnull(uf.f_capacity, 0) > 0 then uf.f_capacity else gm.f_capacity end f_capacity, --表最大量程
            u.f_balance balance,
            u.f_user_level,
            address.f_slice_area f_zones,
            address.f_residential_area area,
            avggas,
            substring(convert(varchar(100),h.f_hand_date,23),0,8) belongmonth,
            h1.maxid
     from  t_handplan h
         left join t_userfiles uf on h.f_userfiles_id=uf.f_userfiles_id
         left join (
             select f_userfiles_id,max(id) maxid,
                sum(f_oughtamount)/count(*) avggas
             from t_handplan
             where f_hand_state='有效' group by  f_userfiles_id
         )   h1 on h.f_userfiles_id=h1.f_userfiles_id
         LEFT JOIN t_userinfo u ON h.f_userinfo_id = u.f_userinfo_id
         left join t_gasbrand gb on uf.f_gasbrand_id = gb.id
         left join t_gasmodel gm on uf.f_gasmodel_id=gm.id
         left join t_meter_book mb on uf.f_meter_book_num=mb.id
         left join t_user_address address on uf.f_useraddress_id = address.id
         left join (select * from t_stairprice where getdate()>=f_perform_date and getdate()<=f_end_date and f_state = '有效') sp on h.f_price_id = sp.f_price_id
     where f_hand_state='有效'  AND  h.f_meter_classify = '机表'
     AND f_table_state = '正常' and f_user_state='正常'
)t
where {condition}
order by {orderitem},f_meter_book_num,f_meter_book_sort,f_residential_area,f_floor,f_adjustable_id
